@@ -1,9 +1,11 @@
 from __future__ import annotations
 
+import datetime
 from dataclasses import dataclass
+from typing import Optional
 
 
-@dataclass(kw_only=True, frozen=True)
+@dataclass(kw_only=True)
 class ClientConfig:
     """
     Used to hold the Client config.
@@ -11,13 +13,14 @@ class ClientConfig:
     username: str
     headers: dict
     cookies: dict
+    last_call_time: datetime
 
 
 class Client:
     """
     This class is used to store and set up initial Client configuration.
     """
-    client_config = None
+    client_config: Optional[ClientConfig] = None
 
     @classmethod
     def set_client_config(cls, *, username: str, sid_cookie: str, csrf_cookie: str) -> None:
@@ -34,9 +37,16 @@ class Client:
 
         client_config = ClientConfig(username=username,
                                      headers=headers,
-                                     cookies=cookies)
+                                     cookies=cookies,
+                                     last_call_time=datetime.datetime.now())
         cls.client_config = client_config
 
     @classmethod
     def get_client_config(cls) -> ClientConfig:
         return cls.client_config
+
+    @classmethod
+    def update(cls, **kwargs) -> None:
+        new_last_call_time = kwargs.pop("last_call_time", None)
+        if new_last_call_time is not None:
+            cls.client_config.last_call_time = new_last_call_time
